summaryrefslogtreecommitdiff
path: root/src/script/api/script_tilelist.hpp
diff options
context:
space:
mode:
authortruebrain <truebrain@openttd.org>2011-11-29 23:15:35 +0000
committertruebrain <truebrain@openttd.org>2011-11-29 23:15:35 +0000
commit98103121d4f2ed1f1581919b7b1f343ccd410c12 (patch)
tree1e760dd6517a6b0f9fb669ec277139a8e3f9a4a3 /src/script/api/script_tilelist.hpp
parentafdb67a3534f85b4efbd3327ece8137211042d7b (diff)
downloadopenttd-98103121d4f2ed1f1581919b7b1f343ccd410c12.tar.xz
(svn r23355) -Codechange: rename all AI* to Script* (Rubidium)
Diffstat (limited to 'src/script/api/script_tilelist.hpp')
-rw-r--r--src/script/api/script_tilelist.hpp46
1 files changed, 23 insertions, 23 deletions
diff --git a/src/script/api/script_tilelist.hpp b/src/script/api/script_tilelist.hpp
index ea0f241bb..e9daacc5d 100644
--- a/src/script/api/script_tilelist.hpp
+++ b/src/script/api/script_tilelist.hpp
@@ -17,23 +17,23 @@
/**
* Creates an empty list, in which you can add tiles.
- * @ingroup AIList
+ * @ingroup ScriptList
*/
-class AITileList : public AIList {
+class ScriptTileList : public ScriptList {
public:
/**
* Adds the rectangle between tile_from and tile_to to the to-be-evaluated tiles.
* @param tile_from One corner of the tiles to add.
* @param tile_to The other corner of the tiles to add.
- * @pre AIMap::IsValidTile(tile_from).
- * @pre AIMap::IsValidTile(tile_to).
+ * @pre ScriptMap::IsValidTile(tile_from).
+ * @pre ScriptMap::IsValidTile(tile_to).
*/
void AddRectangle(TileIndex tile_from, TileIndex tile_to);
/**
* Add a tile to the to-be-evaluated tiles.
* @param tile The tile to add.
- * @pre AIMap::IsValidTile(tile).
+ * @pre ScriptMap::IsValidTile(tile).
*/
void AddTile(TileIndex tile);
@@ -41,15 +41,15 @@ public:
* Remove the tiles inside the rectangle between tile_from and tile_to form the list.
* @param tile_from One corner of the tiles to remove.
* @param tile_to The other corner of the files to remove.
- * @pre AIMap::IsValidTile(tile_from).
- * @pre AIMap::IsValidTile(tile_to).
+ * @pre ScriptMap::IsValidTile(tile_from).
+ * @pre ScriptMap::IsValidTile(tile_to).
*/
void RemoveRectangle(TileIndex tile_from, TileIndex tile_to);
/**
* Remove a tile from the list.
* @param tile The tile to remove.
- * @pre AIMap::IsValidTile(tile).
+ * @pre ScriptMap::IsValidTile(tile).
*/
void RemoveTile(TileIndex tile);
};
@@ -57,47 +57,47 @@ public:
/**
* Creates a list of tiles that will accept cargo for the given industry.
* @note If a simular industry is close, it might happen that this industry receives the cargo.
- * @ingroup AIList
+ * @ingroup ScriptList
*/
-class AITileList_IndustryAccepting : public AITileList {
+class ScriptTileList_IndustryAccepting : public ScriptTileList {
public:
/**
* @param industry_id The industry to create the AITileList around.
* @param radius The radius of the station you will be using.
- * @pre AIIndustry::IsValidIndustry(industry_id).
+ * @pre ScriptIndustry::IsValidIndustry(industry_id).
* @pre radius > 0.
*/
- AITileList_IndustryAccepting(IndustryID industry_id, int radius);
+ ScriptTileList_IndustryAccepting(IndustryID industry_id, int radius);
};
/**
* Creates a list of tiles which the industry checks to see if a station is
* there to receive cargo produced by this industry.
- * @ingroup AIList
+ * @ingroup ScriptList
*/
-class AITileList_IndustryProducing : public AITileList {
+class ScriptTileList_IndustryProducing : public ScriptTileList {
public:
/**
* @param industry_id The industry to create the AITileList around.
* @param radius The radius of the station you will be using.
- * @pre AIIndustry::IsValidIndustry(industry_id).
+ * @pre ScriptIndustry::IsValidIndustry(industry_id).
* @pre radius > 0.
*/
- AITileList_IndustryProducing(IndustryID industry_id, int radius);
+ ScriptTileList_IndustryProducing(IndustryID industry_id, int radius);
};
/**
* Creates a list of tiles which have the requested StationType of the
* StationID.
- * @ingroup AIList
+ * @ingroup ScriptList
*/
-class AITileList_StationType : public AITileList {
+class ScriptTileList_StationType : public ScriptTileList {
public:
/**
* @param station_id The station to create the AITileList for.
* @param station_type The StationType to create the AIList for.
*/
- AITileList_StationType(StationID station_id, AIStation::StationType station_type);
+ ScriptTileList_StationType(StationID station_id, ScriptStation::StationType station_type);
};
#endif /* SCRIPT_TILELIST_HPP */
@@ -57,47 +57,47 @@ public:
public:
/**
- * @param industry_id The industry to create the AITileList around.
+ * @param industry_id The industry to create the ScriptTileList around.
* @param radius The radius of the station you will be using.
@@ -57,47 +57,47 @@ public:
public:
/**
- * @param industry_id The industry to create the AITileList around.
+ * @param industry_id The industry to create the ScriptTileList around.
* @param radius The radius of the station you will be using.
@@ -57,47 +57,47 @@ public:
public:
/**
- * @param station_id The station to create the AITileList for.
- * @param station_type The StationType to create the AIList for.
+ * @param station_id The station to create the ScriptTileList for.
+ * @param station_type The StationType to create the ScriptList for.
*/